@@ -1,7 +1,7 @@
 #include "pdl.h"      /* Data structure declarations */
 #include "pdlcore.h"  /* Core declarations */
 
-#define XCODE(code, datatype, ctype, ppsym, shortctype, defbval) \
+#define XCODE(code, datatype, ctype, ...) \
     ctype *ap = (ctype *) a->data; \
     ctype *pp = (ctype *) a->vafftrans->from->data; \
     pp += a->vafftrans->offs; \
@@ -69,13 +69,13 @@ pdl_error pdl_converttype( pdl* a, int targtype ) {
   ((from_badval_isnan) \
     ? isnan((double)(from_val)) \
     : (from_val) == (from_badval))
-#define X_OUTER(datatype_from, ctype_from, ppsym_from, shortctype_from, defbval_from) \
+#define X_OUTER(datatype_from, ctype_from, ppsym_from, ...) \
     PDL_Indx i = a->nvals; \
     ctype_from *bb = (ctype_from *) b; \
     ctype_from from_badval = pdl_get_pdl_badvalue(a).value.ppsym_from; \
     char from_badval_isnan = PDL_ISNAN_##ppsym_from(from_badval); \
     PDL_GENERICSWITCH2(PDL_TYPELIST2_ALL_, targtype, X_INNER, return pdl_make_error(PDL_EUSERERROR, "Not a known data type code=%d", targtype))
-#define X_INNER(datatype_to, ctype_to, ppsym_to, shortctype_to, defbval_to) \
+#define X_INNER(datatype_to, ctype_to, ppsym_to, shortctype_to, defbval_to, ...) \
     ctype_to *aa = (ctype_to *) a->data; \
     aa += i-1; bb += i-1; \
     if (a->state & PDL_BADVAL) { \
