@@ -142,13 +142,13 @@ PDL_LIST_FLAGS_PARAMS(X)
     NULL
   };
   int typeval[] = {
-#define X(sym, ctype, ppsym, shortctype, defbval) sym,
+#define X(sym, ...) sym,
 PDL_TYPELIST_ALL(X)
 #undef X
     -1
   };
   char *typechar[] = {
-#define X(sym, ctype, ppsym, shortctype, defbval) #sym,
+#define X(sym, ...) #sym,
 PDL_TYPELIST_ALL(X)
 #undef X
     NULL
@@ -483,12 +483,12 @@ void pdl_dump (pdl *it) {
 
 void pdl_dump_anyval(PDL_Anyval v) {
   if (v.type < PDL_CF) {
-#define X(datatype, ctype, ppsym, shortctype, defbval) \
+#define X(datatype, ctype, ppsym, ...) \
     printf("%Lg", (long double)v.value.ppsym);
     PDL_GENERICSWITCH(PDL_TYPELIST2_REAL, v.type, X, printf("(UNKNOWN PDL_Anyval type=%d)", v.type))
 #undef X
   } else {
-#define X(datatype, ctype, ppsym, shortctype, defbval) \
+#define X(datatype, ctype, ppsym, ...) \
     printf("%Lg%+Lgi", creall((complex long double)v.value.ppsym), cimagl((complex long double)v.value.ppsym));
     PDL_GENERICSWITCH(PDL_TYPELIST2_COMPLEX, v.type, X, printf("(UNKNOWN PDL_Anyval type=%d)", v.type))
 #undef X
